"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveComponentModelList = void 0;
const parseTextFieldDescriptor_1 = require("./descriptors/parseTextFieldDescriptor");
const parseTextAreaDescriptor_1 = require("./descriptors/parseTextAreaDescriptor");
const parseNumberDescriptor_1 = require("./descriptors/parseNumberDescriptor");
const parseCheckListDescriptor_1 = require("./descriptors/parseCheckListDescriptor");
const parseCheckBoxDescriptor_1 = require("./descriptors/parseCheckBoxDescriptor");
const parseDateTimeDescriptor_1 = require("./descriptors/parseDateTimeDescriptor");
function deriveComponentModelList(components) {
    const simpleComps = components
        .flatMap((cmp) => cmp.type === "group" ? cmp.components ?? [] : cmp)
        .filter((cmp) => cmp != null && cmp.type != "button");
    return simpleComps
        .map((comp) => {
        switch (comp.type) {
            case "textfield":
                return {
                    type: comp.type,
                    props: (0, parseTextFieldDescriptor_1.parseTextFieldDescriptor)(comp),
                };
            case "textarea":
                return {
                    type: comp.type,
                    props: (0, parseTextAreaDescriptor_1.parseTextAreaDescriptor)(comp),
                };
            case "number":
                return {
                    type: comp.type,
                    props: (0, parseNumberDescriptor_1.parseNumberDescriptor)(comp),
                };
            case "datetime":
                return {
                    type: comp.type,
                    props: (0, parseDateTimeDescriptor_1.parseDateTimeDescriptor)(comp),
                };
            case "checklist":
                return {
                    type: comp.type,
                    props: (0, parseCheckListDescriptor_1.parseCheckListDescriptor)(comp),
                };
            case "checkbox":
                return {
                    type: comp.type,
                    props: (0, parseCheckBoxDescriptor_1.parseCheckBoxDescriptor)(comp),
                };
            case "group":
                throw new Error(`camunda component with type "group" should not exist in array, ` +
                    `but should be flattened on previous step`);
            case "button":
                throw new Error(`camunda component with type "button" should be sorted out ` +
                    ` on previous step, and handled separately`);
        }
    });
}
exports.deriveComponentModelList = deriveComponentModelList;
//# sourceMappingURL=deriveComponentModelList.js.map